@@ -37,18 +37,9 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KAudiocdModule, "kcm_audiocd.json")
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-KAudiocdModule::KAudiocdModule(QWidget *parent, const QVariantList &lst)
-    : KCModule(parent)
-#else
 KAudiocdModule::KAudiocdModule(QObject *parent, const KPluginMetaData &md)
     : KCModule(parent, md)
-#endif
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Q_UNUSED(lst);
-#endif
-
     auto box = new QVBoxLayout(widget());
 
     audioConfig = new AudiocdConfig(widget());
@@ -95,14 +86,6 @@ KAudiocdModule::KAudiocdModule(QObject *parent, const KPluginMetaData &md)
     connect(audioConfig->kcfg_replaceInput, &QLineEdit::textChanged, this, &KAudiocdModule::slotConfigChanged);
     connect(audioConfig->kcfg_replaceOutput, &QLineEdit::textChanged, this, &KAudiocdModule::slotConfigChanged);
     connect(audioConfig->example, &QLineEdit::textChanged, this, &KAudiocdModule::slotConfigChanged);
-
-    auto about = new KAboutData(QStringLiteral("kcmaudiocd"), i18n("KDE Audio CD KIO Worker"), QStringLiteral(AUDIOCDPLUGINS_VERSION_STRING));
-
-    about->addAuthor(i18n("Benjamin C. Meyer"), i18n("Former Maintainer"), QStringLiteral("ben@meyerhome.net"));
-    about->addAuthor(i18n("Carsten Duvenhorst"), i18n("Original Author"), QStringLiteral("duvenhorst@duvnet.de"));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    setAboutData(about);
-#endif
 }
 
 KAudiocdModule::~KAudiocdModule()
@@ -110,13 +93,6 @@ KAudiocdModule::~KAudiocdModule()
     delete config;
 }
 
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 105, 0)
-QWidget *KAudiocdModule::widget()
-{
-    return this;
-}
-#endif
-
 QString removeQoutes(const QString &text)
 {
     QString deqoutedString = text;
@@ -168,7 +144,7 @@ void KAudiocdModule::save() {
         return;
 
     {
-        KConfigGroup cg(config, "CDDA");
+        KConfigGroup cg(config, QStringLiteral("CDDA"));
 
         cg.writeEntry("disable_paranoia", !(audioConfig->ec_enable_check->isChecked()));
         cg.writeEntry("never_skip", !(audioConfig->ec_skip_check->isChecked()));
@@ -176,19 +152,19 @@ void KAudiocdModule::save() {
     }
 
   {
-    KConfigGroup cg(config, "FileName");
-    cg.writeEntry("file_name_template", audioConfig->fileNameLineEdit->text());
-    cg.writeEntry("album_name_template", audioConfig->albumNameLineEdit->text());
-    cg.writeEntry("show_file_location", audioConfig->fileLocationGroupBox->isChecked());
-    cg.writeEntry("file_location_template", audioConfig->fileLocationLineEdit->text());
-    cg.writeEntry("regexp_example", audioConfig->example->text());
+      KConfigGroup cg(config, QStringLiteral("FileName"));
+      cg.writeEntry("file_name_template", audioConfig->fileNameLineEdit->text());
+      cg.writeEntry("album_name_template", audioConfig->albumNameLineEdit->text());
+      cg.writeEntry("show_file_location", audioConfig->fileLocationGroupBox->isChecked());
+      cg.writeEntry("file_location_template", audioConfig->fileLocationLineEdit->text());
+      cg.writeEntry("regexp_example", audioConfig->example->text());
 
-    // save quoted if required
-    QString replaceInput = audioConfig->kcfg_replaceInput->text();
-    QString replaceOutput = audioConfig->kcfg_replaceOutput->text();
-    if (needsQoutes(replaceInput)) {
-        replaceInput = QLatin1Char('\"') + replaceInput + QLatin1Char('\"');
-    }
+      // save quoted if required
+      QString replaceInput = audioConfig->kcfg_replaceInput->text();
+      QString replaceOutput = audioConfig->kcfg_replaceOutput->text();
+      if (needsQoutes(replaceInput)) {
+          replaceInput = QLatin1Char('\"') + replaceInput + QLatin1Char('\"');
+      }
     if (needsQoutes(replaceOutput)) {
         replaceOutput = QLatin1Char('\"') + replaceOutput + QLatin1Char('\"');
     }
@@ -208,22 +184,22 @@ void KAudiocdModule::save() {
 void KAudiocdModule::load() {
 
   {
-    KConfigGroup cg(config, "CDDA");
+      KConfigGroup cg(config, QStringLiteral("CDDA"));
 
-    audioConfig->ec_enable_check->setChecked(!(cg.readEntry("disable_paranoia", false)));
-    audioConfig->ec_skip_check->setChecked(!(cg.readEntry("never_skip", true)));
-    audioConfig->niceLevel->setValue(cg.readEntry("niceLevel", 0));
+      audioConfig->ec_enable_check->setChecked(!(cg.readEntry("disable_paranoia", false)));
+      audioConfig->ec_skip_check->setChecked(!(cg.readEntry("never_skip", true)));
+      audioConfig->niceLevel->setValue(cg.readEntry("niceLevel", 0));
   }
 
   {
-    KConfigGroup cg(config, "FileName");
-    audioConfig->fileNameLineEdit->setText(cg.readEntry("file_name_template", "%{trackartist} - %{number} - %{title}"));
-    audioConfig->albumNameLineEdit->setText(cg.readEntry("album_name_template", "%{albumartist} - %{albumtitle}"));
-    audioConfig->fileLocationGroupBox->setChecked(cg.readEntry("show_file_location", false));
-    audioConfig->fileLocationLineEdit->setText(cg.readEntry("file_location_template", QString()));
-    audioConfig->kcfg_replaceInput->setText(cg.readEntry("regexp_search"));
-    audioConfig->kcfg_replaceOutput->setText(cg.readEntry("regexp_replace"));
-    audioConfig->example->setText(cg.readEntry("example", i18n("Cool artist - example audio file.wav")));
+      KConfigGroup cg(config, QStringLiteral("FileName"));
+      audioConfig->fileNameLineEdit->setText(cg.readEntry("file_name_template", "%{trackartist} - %{number} - %{title}"));
+      audioConfig->albumNameLineEdit->setText(cg.readEntry("album_name_template", "%{albumartist} - %{albumtitle}"));
+      audioConfig->fileLocationGroupBox->setChecked(cg.readEntry("show_file_location", false));
+      audioConfig->fileLocationLineEdit->setText(cg.readEntry("file_location_template", QString()));
+      audioConfig->kcfg_replaceInput->setText(cg.readEntry("regexp_search"));
+      audioConfig->kcfg_replaceOutput->setText(cg.readEntry("regexp_replace"));
+      audioConfig->example->setText(cg.readEntry("example", i18n("Cool artist - example audio file.wav")));
   }
 
   for (int i = 0; i < encoderSettings.size(); ++i) {
@@ -243,11 +219,7 @@ void KAudiocdModule::slotModuleChanged() {
 
 void KAudiocdModule::slotConfigChanged() {
     configChanged = true;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Q_EMIT changed(true);
-#else
     setNeedsSave(true);
-#endif
 }
 
 /*
@@ -265,24 +237,5 @@ void KAudiocdModule::slotEcEnable() {
   slotConfigChanged();
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-QString KAudiocdModule::quickHelp() const
-{
-    return i18n(
-        "<h1>Audio CDs</h1> The Audio CD KIO Worker enables you to easily"
-        " create wav, FLAC, MP3, Ogg Vorbis or Opus files from your "
-        "audio CD-ROMs or DVDs."
-        " The KIO worker is invoked by typing <i>\"audiocd:/\"</i> in "
-        "Dolphin's location"
-        " bar. In this module, you can configure"
-        " encoding, and device settings. Note that FLAC, MP3, Ogg Vorbis,"
-        " and Opus encoding are only available if the corresponding "
-        "libraries (libFLAC for"
-        " FLAC and libvorbis for Ogg) and utilities (lame for MP3 and "
-        "opus-tools for Opus)"
-        " are installed in your system.");
-}
-#endif
-
 #include "kcmaudiocd.moc"
 #include "moc_kcmaudiocd.cpp"
